@@ -1,28 +1,14 @@
-# This program is free software; you can redistribute it and/or modify it under
-# the terms of the GNU General Public License as published by the Free Software
-# Foundation; either version 2 of the License, or (at your option) any later
-# version.
-#
-# This program is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along with
-# this program; if not, write to the Free Software Foundation, Inc.,
-# 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-"""Deprecation utilities
+"""Deprecation utilities.
 
-:author:    Logilab
-:copyright: 2006-2008 LOGILAB S.A. (Paris, FRANCE)
-:contact:   http://www.logilab.fr/ -- mailto:python-projects@logilab.org
+:copyright: 2006-2008 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
+:license: General Public License version 2 - http://www.gnu.org/licenses
 """
 __docformat__ = "restructuredtext en"
 
 import sys
 from warnings import warn
 
-from logilab.common.modutils import LazyObject, load_module_from_name
-
 
 class deprecated(type):
     """metaclass to print a warning on instantiation of a deprecated class"""
@@ -75,9 +61,10 @@ def class_moved(new_class, old_name=None, message=None):
 
 
 def deprecated_function(new_func, message=None):
-    """creates a function which fires a DeprecationWarning when used
+    """Creates a function which fires a DeprecationWarning when used.
 
-    For example, if <bar> is deprecated in favour of <foo> :
+    For example, if <bar> is deprecated in favour of <foo>:
+    
     >>> bar = deprecated_function(foo, 'bar is deprecated')
     >>> bar()
     sample.py:57: DeprecationWarning: bar is deprecated
@@ -105,31 +92,34 @@ def moved(modpath, objname):
     instead (which has no lazy import feature though).
     """
     def callnew(*args, **kwargs):
+        from logilab.common.modutils import load_module_from_name
         message = "object %s has been moved to module %s" % (objname, modpath)
         warn(message, DeprecationWarning, stacklevel=2)
         m = load_module_from_name(modpath)
         return getattr(m, objname)(*args, **kwargs)
     return callnew
 
+# from logilab.common.modutils import LazyObject
 
-class WarnLazyObject(LazyObject):
-    def __init__(self, oldname, newname):
-        # XXX doesn't work if module isn't in a package
-        package, module = newname.rsplit('.', 1)
-        super(WarnLazyObject, self).__init__(package, module)
-        self.oldname = oldname
-        self.newname = newname
-        print 'hop', oldname, newname
-        sys.modules[oldname] = self
+# class WarnLazyObject(LazyObject):
+#     def __init__(self, oldname, newname):
+#         # XXX doesn't work if module isn't in a package
+#         package, module = newname.rsplit('.', 1)
+#         super(WarnLazyObject, self).__init__(package, module)
+#         self.oldname = oldname
+#         self.newname = newname
+#         print 'hop', oldname, newname
+#         sys.modules[oldname] = self
 
-    def __getobj(self):
-        if self._imported is None:
-            message = "module %s has moved, it's now %s" % (
-                self.oldname, self.newname)
-            warn(message, DeprecationWarning, stacklevel=2)
-        return super(WarnLazyObject, self).__getobj()
+#     def __getobj(self):
+#         if self._imported is None:
+#             message = "module %s has moved, it's now %s" % (
+#                 self.oldname, self.newname)
+#             warn(message, DeprecationWarning, stacklevel=2)
+#         return super(WarnLazyObject, self).__getobj()
 
-module_moved = WarnLazyObject
+
+# module_moved = WarnLazyObject
 
 def obsolete(reason="This function is obsolete"):
     """this function is an alternative to `deprecated_function`
