@@ -11,13 +11,16 @@ __docformat__ = "restructuredtext en"
 import os
 import glob
 import shutil
+import stat
 import sys
 import tempfile
 import time
 import fnmatch
+import errno
 from os.path import exists, isdir, islink, basename, join, walk
 
 from logilab.common import STD_BLACKLIST
+from logilab.common.proc import ProcInfo, NoSuchProcess
 
 
 def chown(path, login=None, group=None):
@@ -199,21 +202,48 @@ class Execute:
         os.remove(outfile)
         os.remove(errfile)
 
+def acquire_lock(lock_file, max_try=10, delay=10, max_delay=3600):
+    """Acquire a lock represented by a file on the file system
 
-def acquire_lock(lock_file, max_try=10, delay=10):
-    """Acquire a lock represented by a file on the file system."""
-    count = 0
-    while max_try <= 0 or count < max_try:
-        if not exists(lock_file):
-            break
-        count += 1
-        time.sleep(delay)
+    If the process written in lock file doesn't exist anymore, we remove the
+    lock file immediately
+    If age of the lock_file is greater than max_delay, then we raise a UserWarning
+    """
+    count = abs(max_try)
+    while count:
+        try:
+            fd = os.open(lock_file, os.O_EXCL | os.O_RDWR | os.O_CREAT)
+            os.write(fd, str(os.getpid()))
+            os.close(fd)
+            return True
+        except OSError, e:
+            if e.errno == errno.EEXIST:
+                try:
+                    fd = open(lock_file, "r")
+                    pid = int(fd.readline())
+                    pi = ProcInfo(pid)
+                    age = (time.time() - os.stat(lock_file)[stat.ST_MTIME])
+                    if age / max_delay > 1 :
+                        raise UserWarning("Command '%s' (pid %s) has locked the "
+                                          "file '%s' for %s minutes"
+                                          % (pi.name(), pid, lock_file, age/60))
+                except UserWarning:
+                    raise
+                except NoSuchProcess:
+                    os.remove(lock_file)
+                except Exception:
+                    # The try block is not essential. can be skipped.
+                    # Note: ProcInfo object is only available for linux
+                    # process information are not accessible...
+                    # or lock_file is no more present...
+                    pass
+            else:
+                raise
+            count -= 1
+            time.sleep(delay)
     else:
         raise Exception('Unable to acquire %s' % lock_file)
-    stream = open(lock_file, 'w')
-    stream.write(str(os.getpid()))
-    stream.close()
-    
+
 def release_lock(lock_file):
     """Release a lock represented by a file on the file system."""
     os.remove(lock_file)
